{% extends "galleries/base.html" %}
{% load cache typogrify_tags %}

{% block title %} Photo galleries {% endblock %}

{% block bodyid %}gallery_list{% endblock %}

{% block content %}
  <h1>Photo Galleries</h1>
  <ul class="multi-col three-col">
    {% for gal in gallery_list|dictsort:"created" %}
      <li>
        <a href="{{ gal.get_absolute_url }}">
        <img src="{{ MEDIA_URL }}{{ gal.get_image.image.t_360 }}" alt="{{ gal.description }}">
          <h3>
            {{ gal }}
          </h3>
        </a>
      </li>
    {% endfor %}
  </ul>
{% endblock %}
